package com.engine.htsc.contractmanagement.service;

import java.util.List;
import java.util.Map;

public interface ContractService {

    Map<String, Object> getChangeRecord(Map<String, Object> params)throws Exception;

    Map<String, Object> checkRepeatData(Map<String, Object> params)throws Exception;

    Map<String, Object> queryDataByCustId(Map<String, Object> params)throws Exception;

    Map<String, Object> queryDataByCertNo(Map<String, Object> params)throws Exception;

    Map<String, Object> addOrginfo(Map<String, Object> params)throws Exception;

    Map<String, Object> addCertificate(Map<String, Object> params)throws Exception;

    Map<String, Object> updateOrginfo(Map<String, Object> params)throws Exception;

    Map<String, Object> deleteOrginfo(Map<String, Object> params)throws Exception;

    Map<String, Object> updateCertificate(Map<String, Object> params)throws Exception;

    Map<String, Object> deleteCertificate(Map<String, Object> params)throws Exception;
}
